/* $Id: fusion-acquia-slate-style.css,v 1.2 2010/07/02 23:14:21 eternalistic Exp $ */

/* Basic Typography & Colors
-------------------------------------------------------------- */
/* Add general site styling here for typography and background */
body {
  font-size: 75%;   /* also set in fusion_starter.info: settings[base-font-size] = font-size-12 */
}

/* Default link styles - separate a:visited for a different visited link style */
a,
a:link,
a:visited {
  color: #DFB77C;
  text-decoration: none;
}

/* Hover/active link styles. Don't forget :focus for accessibility */
a:hover,
a:focus,
a:active {
  color: #EBDCC7;
  text-decoration: underline;
}

li a.active {
  color: #fff;
}


/* Specific Typography
-------------------------------------------------------------- */
#site-name {
  color: #525252;
  float: left;
  font-family: Myriad Pro,Myriad Web Pro Regular,Lucida Grande,Geneva,Trebuchet MS,sans-serif;
  font-size: 215.38%; /* 28px/13px */
  font-weight: normal;
  letter-spacing: 3px;
  line-height: 100%;
  position: relative;
  text-transform: uppercase;
  top: 8px;
  white-space: nowrap;
}

#site-name.with-slogan {
  border-right: 1px solid #ddd;
  padding-right: 15px;
}

.footer-message {
  font-size: 90%;
}

h1,h2,h3,h4 {
  font-weight: normal;
}

h1 {
  color: #DFB77C;
  font-size: 169.23; /* 22px/13px */
  font-weight: bold;
  line-height: 125%;
}

h2 {
  font-size: 138.46%; /* 18px/13px */  
  line-height: 125%;
}

h3 {
  font-size: 115.38%; /* 15px/13px */
  line-height: 125%;
}

h4 {
  font-size: 100%; /* 13px/13px */
  height: 125%;
  line-height: 125%;
  margin-bottom: 1.25em;
}

h5 {
  font-size: 100%; /* 13px/13px */
  font-weight: bold;
  margin-bottom: 1.5em;
}

h6 {
  font-size: 100%; /* 13px/13px */
  font-weight: bold;
}


/* HTML Elements
-------------------------------------------------------------- */
/* Add padding here if desired so edges of theme aren't flush with browser window */
html {
  background: #000;
}

body {
  background: #292929;
  color: #F0F0F0;
}


/* Site Info
-------------------------------------------------------------- */
/* Wrapper around logo, site name, and slogan */
#header-site-info {
  width: 100%;
}

/* Add float here to put logo and site name side by side, also add margins as
  needed */
#logo {
  float: left;
  margin: 0 10px 0 0;
}

/* Link and hover styles for site name */
#site-name a:link,
#site-name a:visited,
#site-name a:hover,
#site-name a:active {
  color: #525252;
}

/* Typography for site slogan */
#slogan {
  color: #525252;
  display: block;
  float: left;
  font-size: 115.38%; /* 15px/13px */
  font-weight: bold;
  margin: 14px 15px 0 15px;
}


/* Regions
-------------------------------------------------------------- */
#page {
  padding: 1.5em 0 0 0;
}

.page-inner {
  border: 0;
  margin-bottom: 0;
  padding: 0;
}


/* Header Regions
-------------------------------------------------------------- */
#header-site-info {
  padding-bottom: 10px;
}

#header-site-info-inner {
  background: #fff url(../images/sitename-bg.png) no-repeat top right;
  height: 100%;
  padding: 30px 20px;
}

.header-inner {
  color: #525252;
}

#header-wrapper {
  clear: right;
}

.header-wrapper {
  color: #666;
}


/* Primary Menu
/-------------------------------------------------------------- */
#primary-menu {
  float: right;
  margin: 0;
  padding-bottom: 10px;
  width: auto;
}

#primary-menu.block {
  margin: 0 10px;
  overflow: visible;
  position: relative;
  z-index: 101;
}

#primary-menu.block .inner {
  margin: 0;
}

#primary-menu ul.menu {
  font-size: 107.8%; /* 14px/13px */
}

#primary-menu ul.menu li {
  display: block;
  float: left;
  margin: 0 0 0 5px;
  padding: 0 0 0 10px;
  position: relative;
}

#primary-menu ul.menu li a:link,
#primary-menu ul.menu li a:visited {
  color: #999;
  display: block;
  height: 28px;
  line-height: 28px;
  padding: 0 10px 0 0;
  text-decoration: none;
}

#primary-menu ul.menu li a:hover,
#primary-menu ul.menu li a:focus,
#primary-menu ul.menu li a:active,
#primary-menu ul.menu li.active-trail a:link,
#primary-menu ul.menu li.active-trail a:visited  {
  color: #fff;
}

/* Second level - Hovers for parent menu item */
#primary-menu ul.menu li a:hover,
#primary-menu ul.menu li:hover a,
#primary-menu ul.menu li.hover a,
#primary-menu ul.menu li.active-trail a:link,
#primary-menu ul.menu li.active-trail a:visited {
  background: url(../images/primary-menu.png) no-repeat 100% -28px;
  color: #fff;
}

#primary-menu ul.menu li:hover,
#primary-menu ul.menu li.hover,
#primary-menu ul.menu li.active-trail {
  background: url(../images/primary-menu.png) no-repeat -170px 0;
}

/* Second level */
#primary-menu ul.menu li:hover ul.menu,
#primary-menu ul.menu li.hover ul.menu,
#primary-menu ul.menu li.sfHover ul.menu {
  background: url(../images/primary-menu.png) no-repeat left 100%;
  font-family: Tahoma, Verdana, Arial, Helvetica, sans-serif;
  font-size: 75%;
  margin: -2px 0 0 0;
  padding: 0 0 4px 0;
  position: absolute;
  text-align: left;
  text-transform: none;
  width: 160px;
  z-index: 2;
}

#primary-menu ul.menu li:hover ul.menu li,
#primary-menu ul.menu li.hover ul.menu li,
#primary-menu ul.menu li.sfHover ul.menu li {
  background: #646464;
  margin-left: 0;
  padding-left: 5px;
  width: 155px;
}

#primary-menu ul.menu li:hover ul.menu li a:link,
#primary-menu ul.menu li:hover ul.menu li a:visited,
#primary-menu ul.menu li.hover ul.menu li a:link,
#primary-menu ul.menu li.hover ul.menu li a:visited,
#primary-menu ul.menu li.sfHover ul.menu li a:link,
#primary-menu ul.menu li.sfHover ul.menu li a:visited {
  border-bottom: 1px solid #888;
  margin-right: 5px;
  padding-left: 5px;
}

#primary-menu ul.menu li:hover ul.menu li.first,
#primary-menu ul.menu li.hover ul.menu li.first,
#primary-menu ul.menu li.sfHover ul.menu li.first {
  background: #646464 url(../images/primary-menu.png) no-repeat -5px 0;
}

#primary-menu ul.menu li:hover ul.menu li.last a:link,
#primary-menu ul.menu li:hover ul.menu li.last a:visited ,
#primary-menu ul.menu li.hover ul.menu li.last a:link,
#primary-menu ul.menu li.hover ul.menu li.last a:visited,
#primary-menu ul.menu li.sfHover ul.menu li.last a:link,
#primary-menu ul.menu li.sfHover ul.menu li.last a:visited {
  border-bottom: 0;
}

#primary-menu ul.menu li ul.menu li a:link,
#primary-menu ul.menu li ul.menu li a:visited {
  background: #646464;
  color: #e1e1e1;
  padding-left: 10px;
}

#primary-menu ul.menu li ul.menu li a:hover {
  color: #fff;
}

#primary-menu ul.menu li ul.menu li a.active {
  text-decoration: underline;
}

/* Third level */
#primary-menu ul.menu li:hover ul.menu li ul.menu,
#primary-menu ul.menu li.hover ul.menu li ul.menu {
  background: none;
  font-size: 100%; /* 11px/12px */
  margin-left: 50px;
  margin-top: 0;
}

#primary-menu ul.menu li:hover ul.menu li ul.menu li.first,
#primary-menu ul.menu li.hover ul.menu li ul.menu li.first,
#primary-menu ul.menu li.sfHover ul.menu lu ul.menu li.first {
  background: #646464;
}

/* Primary menu - Nolink */
#primary-menu ul.menu li span.nolink  {
  color: #999;
  display: block;
  height: 28px;
  line-height: 28px;
  padding: 0 10px 0 0;
  text-decoration: none;
}

#primary-menu ul.menu li span.nolink:hover,
#primary-menu ul.menu li span.nolink.hover,
#primary-menu ul.menu li:hover span.nolink,
#primary-menu ul.menu li.hover span.nolink {
  background: url(../images/primary-menu.png) no-repeat 100% -28px;
  color: #fff;
}

#primary-menu ul.menu li.active-trail span.nolink {
  background: url(../images/primary-menu.png) no-repeat 100% -28px;
  color: #fff;
}

#primary-menu ul.sf-menu li.sfHover ul.menu li span.nolink,
#primary-menu ul.menu li:hover ul.menu li span.nolink,
#primary-menu ul.menu li.hover ul.menu li span.nolink {
  background: #646464;
  color: #e1e1e1;
  padding-left: 5px;
}

#primary-menu ul.menu li:hover ul.menu li span.nolink:hover,
#primary-menu ul.menu li.hover ul.menu li span.nolink.hover {
  color: #fff;
}


/* Secondary menu
-------------------------------------------------------------- */
#secondary-menu {
  float: right;
  margin: 0;
  width: auto;
}

#secondary-menu.block {
  margin: -20px 10px 10px 0;
  overflow: visible;
  position: relative;
  z-index: 101;
}

#secondary-menu.block .inner {
  margin: 0;
}

#secondary-menu ul.links {
  font-size: 100%; /* 13px/13px */
}

#secondary-menu ul.links li {
  display: block;
  float: left;
  margin: 0 0 0 5px;
  padding: 0 0 0 10px;
  position: relative;
}

#secondary-menu ul.links li a:link,
#secondary-menu ul.links li a:visited {
  color: #999;
  display: block;
  height: 28px;
  line-height: 28px;
  padding: 0 10px 0 0;
  text-decoration: none;
}

#primary-menu ul.links li a:hover,
#primary-menu ul.links li a:focus,
#primary-menu ul.links li a:active,
#primary-menu ul.links li.active-trail a:link,
#primary-menu ul.links li.active-trail a:visited  {
  color: #fff;
}

/* Second level - Hovers for parent menu item */
#secondary-menu ul.links li a:hover,
#secondary-menu ul.links li:hover a,
#secondary-menu ul.links li.hover a,
#secondary-menu ul.links li.active-trail a:link,
#secondary-menu ul.links li.active-trail a:visited {
  background: url(../images/secondary-menu.png) no-repeat 100% -28px;
  color: #fff;
}

#secondary-menu ul.links li:hover,
#secondary-menu ul.links li.hover,
#secondary-menu ul.links li.active-trail {
  background: url(../images/secondary-menu.png) no-repeat -170px 0;
}


/* Header - Search
-------------------------------------------------------------- */
#search-box {
  float: right;
  position: relative;
  top: 10px;
  width: auto;
}

#search-box.block .inner {
  margin: 0;
  text-align: right;
}

#search-input .form-text {
  border: 1px solid #d5d5d5;
  color: #292929;
  float: left;
  margin-right: 10px;
  width: 150px;
}

#search-button {
  position: absolute;
  right: 0;
  top: 3px;
}


/*  Preface Regions
-------------------------------------------------------------- */
#header-site-info.with-preface-top {
  margin-bottom: -10px;
}

#preface-top-wrapper {
  margin-bottom: .5em;
}

#preface-top .preface-top-inner .inner  {
  padding: 30px 10px 0 ;
}


/*  Main Area (content + sidebars + preface bottom + postscript top)
-------------------------------------------------------------- */
.main-wrapper {
  margin-bottom: 20px;
}

/* Layout - First/Main */
.layout-first-main #sidebar-first {
  margin-left: -1px;
}

.layout-first-main #main-group {
  border-left: 1px solid #444;
}

.layout-first-main .content-inner-inner, 
.layout-first-main .preface-bottom-inner {
  padding: 0 0 0 50px;
}

/* Layout - First/Main/Last */
.layout-first-main-last #sidebar-first {
  margin-left: -1px;
}

.layout-first-main-last #main-group {
  border-left: 1px solid #444;
}

.layout-first-main-last #content-group {
  border-right: 1px solid #444;
}

.layout-first-main-last #sidebar-last {
  margin-left: -2px;
}

.layout-first-main-last .content-inner-inner {
  padding: 0 20px 0 20px;
}

/* Layout - Main/Last */
.layout-main-last #sidebar-last{
  margin-right: -1px;
}

.layout-main-last #content-group {
  border-right: 1px solid #444;
}

.layout-main-last .content-inner-inner {
  padding: 0 60px 0 0;
}

/* Sidebars - First */
.sidebars-both-first #main-group {
  border-left: 1px solid #444;
  border-right: none;
}

.sidebars-both-first #content-group {
  border-left: 1px solid #444;
  border-right: none;
}

/* Sidebars - Last */
.sidebars-both-last #main-group {
  border-left: none;
  border-right: 1px solid #444;
}


/* Content Regions
-------------------------------------------------------------- */
.content {
  margin-bottom: 20px;
}


/*  Postscript & Footer Regions
-------------------------------------------------------------- */
.postscript-top {
  margin-top: 1.5em;
}

.footer-wrapper {
  background: #000;
  color: #999;
  padding: 20px 0 0 0;
}

.footer-message-wrapper {
  background: #000;
  color: #999;
  padding: 20px 0 0 0;
  text-align: center;
}


/* Default node styles
/-------------------------------------------------------------- */
/* Change unpublished and preview colors for dark background themes */
.node-unpublished {
  background-color: #fff4f4;
}
.preview .node {
  background-color: #ffffea;
}

/* Typography for node titles */
h2.title {
  font-size: 153.8%; /* 20px/13px */
}

/* Colors and styles for linked node titles */
h2.title a:link,
h2.title a:visited {
  color: #DFB77C;
}

h2.title a:hover,
h2.title a:focus,
h2.title a:active {
  color: #F2F2F2;
  text-decoration: none;
}

/* Links for nodes (taxonomy, commenting, read more, etc) */
div.links,
.node div.links,
div.terms {
  background: #444;
  font-size: 107.6%; /* 14px/13px */
  margin: 0 0 10px 0;
  padding: 5px 10px;
}

div.links ul,
div.terms ul {
  margin: 0;
  padding: 0;
}

div.links ul li,
div.terms ul li {
  color: #C6C6C6;
  font-weight: normal;
  line-height: 130%;
}

div.links ul li a:link,
div.links ul li a:visited,
div.terms ul li a:link,
div.terms ul li a:visited {
  color: #f0f0f0;
  font-weight: bold;
  padding-right: 14px;
}

div.links ul li a:hover,
div.links ul li a:focus,
div.terms ul li a:hover,
div.terms ul li a:focus {
  color: #dfb77c
}

.picture {
  float: right;
  margin: 0 0 15px 15px;
}

.picture img {
  border: 1px solid #444;border
}

/* Just more/read more links */
div.node .read-more a,
div.node .more-link a {
}

blockquote {
  color: #999;
  font-style: italic;
  margin: 1.5em;
}

hr {
  height: 1px;
  border: 1px solid gray;
}


/* Default block styles
/-------------------------------------------------------------- */
h2.block-title {
  font-size: 107.6%; /* 14px/13px */
}


/* Drupal messages
/-------------------------------------------------------------- */
/* Error that appears when a required form field is not filled out */
.form-item input.error,
.form-item textarea.error,
.form-item select.error {
  border: 1px solid #aa1144;
}

/* Required field */
.marker,
.form-required {
  color: #aa1144;
}


/* Pagers
-------------------------------------------------------------- */
ul.pager {
  font-size: 100%; /* 13px/13px */
}

ul.pager a:link,
ul.pager a:visited,
ul.pager li.pager-current {
  border-color: #000;
  color: #DFB77C;
}

ul.pager li.pager-current {
  background-color: #000;
}

ul.pager a:hover,
ul.pager a:active,
ul.pager a:focus {
  background-color: #000;
}

/* Forms
/-------------------------------------------------------------- */
/* Typography and backgrounds for all form buttons */
form input.form-submit {
  background-color: #4D4D4D;
  border: 1px solid #000;
  color: #fff;
  font-size: 100%; /* 13px/13px */
  font-weight: normal;
  height: 25px;
  margin: 0;
  padding: 0 6px 2px 6px;
}

/* Hover style for form buttons */
form input.form-submit:hover,
form input.form-submit.hover,
form input.form-submit:focus {
  background: #3D3D3D;
  cursor: pointer;
}

/* Grippie */
.form-item .resizable-textarea .grippie {
  background-color: #4D4D4D;
  border: 1px solid #6D6D6D;
  border-top: none;
}

/* Typography, background, borders, padding for form fields */
.form-item input,
.form-item select,
.form-item textarea {
  background: #1f1f1f;
  border: 1px solid #6D6D6D;
  color: #eee;
  margin: 0;
  padding: 2px;
}

.form-item input.error,
.form-item textarea.error,
.form-item select.error {
  border: 1px solid #DD7777;
  background: #FFCCCC;
  color: #8A1F11;
}

.form-item .description {
  font-size: 84.6%; /* 11px/13px */
  line-height: 150%;
}

/* Remove backgrounds and border on radios and checkboxes */
.form-item .form-radio,
.form-item .form-checkbox {
  background: inherit;
  border: none !important;
}

/* Fieldset wrapper around groups of form elements -- add border here */
fieldset {
  background: #3E3E3E;
  border: 1px solid #555;
  margin: 15px 0;
  padding: 0 15px 15px 15px;
}

/* Typography and spacing for legend of fieldsets */
fieldset legend {
  display: block;
  font-size: 100%; /* 13px/13px */
  background: #1B1B1B;
  border: 1px solid #555;
  font-weight: bold;
  padding: 0 5px;
}

html.js fieldset.collapsed {
  background: none;
  margin-bottom: 20px;
}

html.js fieldset.collapsible legend a {
  background: transparent url(../images/menu-expanded.gif) no-repeat 0% 50%;
  text-decoration: none;
}

html.js fieldset.collapsed legend a {
  background: transparent url(../images/menu-collapsed.gif) no-repeat 0% 50%;
}

html.js fieldset legend:hover,
html.js fieldset legend.hover{
  background-color: #555;
  border: 1px solid #000;
}

html.js input.form-autocomplete {
  background-position: 100% 5px;
  max-width: 96%;
}

input.text:focus, 
input.title:focus,
textarea:focus, 
select:focus {
  border: 1px solid #666;
}

html.js input.form-autocomplete {
  background-position: 100% 2px;
  background-image: url(../images/throbber-small.gif);
  max-width: 96%;
}

html.js input.throbbing {
  background-position: 100% -16px;
}


/* Buttons
-------------------------------------------------------------- */
span.button-wrapper {
  cursor: pointer;
}

span.button {
  background: transparent url(../images/submit-button-right.png) no-repeat right top;
  display: -moz-inline-box;        /* for FF2 */
  display: inline-block;
  height: 33px;
  padding: 0 10px 0 0;
  position: relative;
}

span.button span {
  background: transparent url(../images/submit-button.png) no-repeat left top;
  display: -moz-inline-box;        /* for FF2 */
  display: inline-block;
  height: 33px;
  margin-right: -2px;
  padding: 0 0 0 9px;
}

span.button span input {
  background-color: transparent;
  border: 0;
  color: #fff;
  cursor: pointer;        /* for Opera */
  font-size: 107.6%; /* 14px/13px */
  height: 33px;
  margin: 0 !important;
  padding: 0;
  white-space: nowrap !important;
}

span.button-wrapper:hover span.button {
  background-position: right -33px;
}

span.button-wrapper:hover span.button span {
  background-position: left -33px;
}

span.button span input:hover {
  background-color: transparent;
}


/* Tables
-------------------------------------------------------------- */
/* Body of tables */
tbody {
  border-top: 1px solid #ccc;
}

/* Header of tables */
thead th,
th {
  border-bottom: 3px solid #000;
}

tbody th {
  border-bottom: 1px solid #ccc;
}

/* Alternating row background styles */
tr.even,
tr.even td {
  background-color: #242424;
  border-bottom: 1px solid #000;
}

tr.odd,
tr.odd td {
  background-color: #303030;
  border-bottom: 1px solid #000;
}

tr.drag td,
tr.drag-previous td {
  color: #E09010;
}

td {
  padding: 3px 8px;
}

/* Log files pages */
tr.selected a,
#admin-dblog tbody a,
table.system-status-report a,
table.update a,
.update table.version a {
  color: #0D57A3;
  text-decoration: none;
}

table.update tr.error td {
  background: #FFFFDD;
}

tr.selected a:hover,
#admin-dblog tbody a:hover,
table.system-status-report a:hover,
table.update a:hover,
.update table.version a:hover {
  text-decoration: underline;
}
  
table.system-status-report th {
  border-bottom: 1px solid #000;
}

tr.info,
tr.info td {
  background: #4D4D4D;
}

tr.ok.even,
tr.ok.odd,
tr.ok.even td,
tr.ok.odd td {
  background: #C2F5C2;
  color: #000;
}

tr.dblog-notice {
  background: #E4EEF8;
  color: #000;
}

tr.warning.even,
tr.warning.odd,
tr.warning.even td,
tr.warning.odd td,
tr.dblog-warning.even,
tr.dblog-warning.odd, 
tr.dblog-warning.even td,
tr.dblog-warning.odd td {
  background: #FFFFDD;
  color: #000;
}

tr.error.even,
tr.error.odd,
tr.dblog-error.odd,
tr.dblog-error.even {
  background: #FBDBDB;
  color: #8A1F11;
}

/* Sticky header */
table.sticky-header {
  background: #000;
}

table.sticky-header thead th {
  padding: 5px;
}


/*--------------------------------------------------------------*/
/* Module styles
/-------------------------------------------------------------- */


/* Book
/-------------------------------------------------------------- */
.book-navigation .menu {
  border-top: 1px solid #ccc;
}

.book-navigation .page-links {
  border-top: 1px solid #ccc;
  border-bottom: 1px solid #ccc;
}


/* Comments
/-------------------------------------------------------------- */
h2.comments-header {
  background: url(../images/icon-commentbubble.png) no-repeat 0 7px;
  border-bottom: 1px dotted #98846C;
  font-family: Arial Narrow, Helvetica, Arial, sans-serif;
  font-size: 153.8%; /* 20px/13px */
  font-weight: bold;
  padding: 0 0 10px 25px;
  text-transform: uppercase;
}

/* Subject (title) of each comment */
div.comment h3.title {
  font-size: 123.1%; /* 16px/13px */
  font-weight: normal;
  margin: 0 0 5px 0;
}

.comment h3.title a:link,
.comment h3.title a:visited {
  text-decoration: none;
}

.comment .submitted {
  color: #E8DCC4;
  margin-bottom: 10px;
}

div.comment .submitted a {
  font-weight: bold;
}

/* Alternating styles for even/odd comments */
.comments div.odd {
  background-color: inherit;
}

#comments div.even {
  background-color: #343434;
}

/* A special highlight style for a comment by the author of the node */
.comments div.comment-by-author {
  background-color: #444;
  border: 3px solid #212121;
}

/* Comment signatures */
.signature {
  border-top: 1px solid #d6ddb9;
}

/* User avatars in comments */
.comment-wrapper .picture img {
}

.comments div.links {
  background: none;
}

.comment div.links a:link,
.comment div.links a:visited {
  color: #E2B57C;
  padding: 0;
  text-decoration: underline;
}

.comment div.links ul li {
  border-right: 1px solid #E2B57C;
  font-size: 84.6%; /* 11px/13px */
  line-height: 100%;
  padding: 0 8px 0 5px;
}

.comment div.links ul li.first {
  padding-left: 0;
}

.comment div.links ul li.last {
  border: none;
  padding-right: 0;
}


/* Forum
/-------------------------------------------------------------- */
.forum-topic-navigation {
  border-top: 1px solid #888;
  border-bottom: 1px solid #888;
}


/* Poll
/-------------------------------------------------------------- */
div.poll div.bar {
  background-color: #ddd;
}

div.poll div.bar div.foreground {
  background-color: #999;
}


/* Profiles
/-------------------------------------------------------------- */
/* Styles for sub-headings on user profiles */
.profile .picture {
  float: none;
}

.profile dt {
  background-color: none;
  padding: 0;
}


/* Tab Menus
/-------------------------------------------------------------- */
#content-tabs {
  background-color: transparent;
  float: left;
  margin: 20px 0;
  padding: 0;
}

#content-tabs ul.primary,
#content-tabs ul.secondary {
  border-bottom: 1px solid #000;
  clear: both;
  float: left;
  margin: 0;
  padding: 0 10px;
}

#content-tabs ul.secondary {
  border-bottom: 1px solid #555;
  margin-top: 10px;
  text-transform: lowercase;
}

#content-tabs ul.primary li,
#content-tabs ul.secondary li {
  border-style: none;
  display: inline;
  float: left;
  list-style: none;
  margin: 0 10px;
  padding: 0;
}

#content-tabs ul.primary li a:link,
#content-tabs ul.primary li a:visited,
#content-tabs ul.secondary li a:link,
#content-tabs ul.secondary li a:visited {
  background-color: transparent;
  border: none;
  color: #000;
  float: left;
  font-weight: bold;
  margin: 0;
  padding: 0 0 6px 0;
  text-decoration: none;
  white-space: nowrap;
}

#content-tabs ul.primary li a:link,
#content-tabs ul.primary li a:visited {
  color: inherit;
  font-size: 107.8%; /* 14px/13px */
  font-weight: bold;
}

#content-tabs ul.secondary li a:link,
#content-tabs ul.secondary li a:visited {
  color: #555;
}

#content-tabs ul.primary li a.active:link,
#content-tabs ul.primary li a.active:visited {
  border-bottom: 4px solid #DFB77C;
  color: #999;
  padding-bottom: 2px;
}

#content-tabs ul.secondary li a.active:link,
#content-tabs ul.secondary li a.active:visited {
  border-bottom: 4px solid #555;
  color: #777;
  padding-bottom: 2px;
}

#content-tabs ul.primary li a:hover,
#content-tabs ul.primary li a:focus,
#content-tabs ul.secondary li a:hover,
#content-tabs ul.secondary li a:focus {
  border-bottom: 4px solid #777;
  color: #777;
  padding-bottom: 2px;
}

#content-tabs ul.primary li a:hover,
#content-tabs ul.primary li a:focus {
  border-bottom: 4px solid #DFB77C;
  color: #999;
}


/* Skinr styles
/-------------------------------------------------------------- */
/* Fusion - List bottom border */
.fusion-list-bottom-border ul li {
  border-bottom: 1px solid #444;
  font-weight: bold;
}

.fusion-list-bottom-border ul li ul {
  border-top: 1px solid #444;
  font-size: 85.7%; /* 12px/13px */
}

.fusion-list-bottom-border ul li ul li.last {
  border-top: 1px solid #444;
  margin-bottom: -1px;
  margin-top: -1px;
}

.fusion-list-bottom-border .inner ul li ul li ul {
  font-size: 100%; /* 13px/13px */
}

/* Fusion - List vertical spacing */
.fusion-list-vertical-spacing .inner ul {
  margin: 0 0 10px 0;
}

.fusion-list-vertical-spacing .inner ul li {
  list-style: none;
  margin-bottom: 10px;
}

.fusion-list-vertical-spacing .inner ul li a:link,
.fusion-list-vertical-spacing .inner ul li a:visited {
  color: #b2b2b2;
}

.fusion-list-vertical-spacing .inner ul li.active-trail a:link,
.fusion-list-vertical-spacing .inner ul li.active-trail a:visited {
  background: url(../images/menu-arrow-white.png) no-repeat 0 4px;
  color: #f6f6f6;
  font-weight: bold;
  padding-left: 10px;
}

.fusion-list-vertical-spacing .inner ul li a:hover,
.fusion-list-vertical-spacing .inner ul li a:focus {
  color: #e0b47a;
}

.fusion-list-vertical-spacing .inner ul li ul {
  font-size: 85.7%; /* 12px/13px */
  margin: 10px 0 10px 10px;
}

.fusion-list-vertical-spacing .inner ul li ul li {
  margin-bottom: 5px;
}

.fusion-list-vertical-spacing .inner ul li ul li a:link,
.fusion-list-vertical-spacing .inner ul li ul li a:visited,
.fusion-list-vertical-spacing .inner ul li.active-trail ul li a:link,
.fusion-list-vertical-spacing .inner ul li.active-trail ul li a:visited {
  background: none;
  color: #fff;
  font-weight: normal;
  padding-left: 0;
}

.fusion-list-vertical-spacing .inner ul li ul li a:hover,
.fusion-list-vertical-spacing .inner ul li ul li a:focus,
.fusion-list-vertical-spacing .inner ul li.active-trail ul li a:hover,
.fusion-list-vertical-spacing .inner ul li.active-trail ul li a:focus {
  color: #e0b47a;
}

.fusion-list-vertical-spacing .inner ul li.active-trail ul li a.active {
  color: #e0b47a;
  text-decoration: underline;
}

.fusion-list-vertical-spacing .inner ul li ul li ul {
  font-size: 100%; /* 13px/13px */
}

/* Superfish vertical menus */
.superfish-vertical {
  position: relative;
  z-index: 10;
}

ul.sf-vertical {
  background: #fafafa;
  margin: 0;
}

ul.sf-vertical li {
  padding: 0;
  border-bottom: 1px solid #ccc;
  line-height: 200%; /* 24px */
  font-weight: bold;
  list-style: none;
  list-style-type: none;
  list-style-image: none;
}

ul.sf-vertical li a:link,
ul.sf-vertical li a:visited,
ul.sf-vertical li .nolink {
  margin-left: 10px;
  padding: 2px;
}

ul.sf-vertical li a:hover,
ul.sf-vertical li a.active {
  text-decoration: underline;
}

ul.sf-vertical li ul {
  background: #fafafa;
  border-top: 1px solid #ccc;
  margin-left: 0;
}

ul.sf-vertical li ul li.last {
  border-top: 1px solid #ccc;
  margin-bottom: -1px;
  margin-top: -1px;
}

ul.sf-vertical li ul {
  border-top: none;
  padding: 4px 0;
}

ul.sf-vertical li ul li {
  border-bottom: none;
  line-height: 150%; /* 24px */
}

ul.sf-vertical li ul li.last {
  border-top: none;
}

ul.sf-vertical li ul li ul {
  margin-top: -4px;
}

/* Rounded corners with gradient background and border */
.rounded-corners-gradient-background .corner {
  display: block;
  height: 20px;
  position: relative;
  width: 20px;
  z-index: 10;
}

.rounded-corners-gradient-background .corner-top-right,
.rounded-corners-gradient-background .corner-bottom-right {
  float: right;
}

/* Rounded corners - Gradient background */
.rounded-corners-gradient-background .corner-top-left {
  background: url(../images/rounded-block.png) no-repeat top left;
  left: -2px;
  top: -2px;
}

.rounded-corners-gradient-background .corner-top-right {
  background: url(../images/rounded-block.png) no-repeat top right;
  right: -2px;
  top: -2px;
}

.rounded-corners-gradient-background .corner-bottom-left {
  background: url(../images/rounded-block.png) no-repeat bottom left;
  left: -2px;
  top: 2px;
}

.rounded-corners-gradient-background .corner-bottom-right {
  background: url(../images/rounded-block.png) no-repeat bottom right;
  right: -2px;
  top: 2px;
}

.rounded-corners-gradient-background .inner {
  background: #292929 url(../images/background-gradient.png) repeat-x bottom center;
  border: 2px solid #4b4b4b;
}

.rounded-corners-gradient-background h2.block-title,
.rounded-corners-gradient-background .content {
  margin: 0 20px;
}

/* Rounded corners with gray background */
.rounded-corners-gray-background .inner {
  background: #3a3a3a;
  padding: 20px;
}

/* White title with bold first word and capital letters */
.title-white-bold-first h2.block-title .first-word {
  font-weight: bold;
}

.title-white-bold-first h2.block-title {
  font-weight: normal;
  text-transform: uppercase;
}

/* Bold white title with capital letters */
.title-white-bold h2.block-title {
  font-weight: bold;
  letter-spacing: -1px;
  text-transform: uppercase;
}

/* Dual color bold title and capital letters */
.title-dual h2.block-title {
  font-weight: bold;
  letter-spacing: -1px;
  text-transform: uppercase;
}

.title-dual-color h2.block-title span.first-word {
  color: #e0b47a;
}

/* Dual color bold title and capital letters with arrow */
.title-dual-color-arrow h2.block-title {
  background: url(../images/block-title-arrow.png) no-repeat 0 3px;
  padding-left: 10px;
}

.title-dual-color-arrow h2.block-title span.first-word {
  color: #e0b47a;
}

/* Yellow title with bold and capital letters */
.title-yellow-bold h2.block-title {
  color: #f9ca8c;
  font-weight: bold;
  letter-spacing: -1px;
  text-transform: uppercase;
}

/* Fusion horizontal user login */
.fusion-horiz-login .item-list li a {
  font-size: 75%;
}

.fusion-horiz-login span.button {
  background: transparent url(../images/submit-button-right-small.png) no-repeat right top;
  height: 25px;
}

.fusion-horiz-login span.button span {
  background: transparent url(../images/submit-button-small.png) no-repeat left top;
  font-size: 76.9%; /* 10px/13px */
  height: 25px;
}

.fusion-horiz-login span.button span input {
  height: 25px;
}

.fusion-horiz-login span.button-wrapper:hover span.button {
  background-position: right -25px;
}

.fusion-horiz-login span.button-wrapper:hover span.button span {
  background-position: left -25px;
}

.fusion-horiz-login label {
  color: #999;
}

/* Preface top - Fusion callout */
.preface-top .fusion-callout {
  bottom: 0;
  line-height: 200%;
  position: absolute;
  right: 0;
}

.preface-top .block.fusion-callout {
  margin-bottom: 0;
}

.preface-top .fusion-callout .inner {
  color: #fff;
  font-size: 200%; /* 26px/13px */
  font-weight: normal;
}

/* Dark transparent background */
.block.dark-transparent-background {
  margin-bottom: 0;
  margin-left: 20px;
}

.dark-transparent-background .inner {
  background: url(../images/transparency-dark.png);
  min-height: 390px;
}

/* Preface top - Banners */
.banner-background #preface-top {
  margin-bottom: 2.5em;
}

.banner-background #preface-top .preface-top-inner {
  height: 420px;
  overflow: hidden;
}

.banner-background-beachstones #preface-top .preface-top-inner {
  background: url(../images/banner/beachstones.jpg) no-repeat center center;
}

.banner-background-citystreetlights #preface-top .preface-top-inner {
  background: url(../images/banner/citystreetlights.jpg) no-repeat center center;
}

.banner-background-greekheads #preface-top .preface-top-inner {
  background: url(../images/banner/greekheads.jpg) no-repeat center center;
}

.banner-background-seascape #preface-top .preface-top-inner {
  background: url(../images/banner/seascape.jpg) no-repeat right top;
}

.banner-background-windows #preface-top .preface-top-inner {
  background: url(../images/banner/windows.jpg) no-repeat right top;
}

/* Content top - Banners */
.banner-background #content-top-wrapper {
  margin-bottom: 2.5em;
}

.banner-background-beachstones #content-top-wrapper .content-top-inner {
  background: url(../images/banner/beachstones.jpg) no-repeat center center;
}

.banner-background-citystreetlights #content-top-wrapper .content-top-inner {
  background: url(../images/banner/citystreetlights.jpg) no-repeat left center;
}

.banner-background-greekheads #content-top-wrapper .content-top-inner {
  background: url(../images/banner/greekheads.jpg) no-repeat left center;
}

.banner-background-seascape #content-top-wrapper .content-top-inner {
  background: url(../images/banner/seascape.jpg) no-repeat left bottom;
}

.banner-background-windows #content-top-wrapper .content-top-inner {
  background: url(../images/banner/windows.jpg) no-repeat left bottom;
}

.banner-background #content-top-wrapper #content-top-inner-inner {
  padding-top: 80px;
}

.banner-background #content-top-wrapper #content-top {
  background: url(../images/content-top-bg.png);
  color: #000;
  margin-left: 0;
  margin-right: 0;
  padding: 10px;
}

.banner-background #content-top-wrapper .content-top-inner .block {
  margin: 0;
}

.banner-background #content-top-wrapper .content-top-inner .inner a:link,
.banner-background #content-top-wrapper .content-top-inner .inner a:visited {
  color: #000;
  font-weight: bold;
  text-decoration: underline;
}


/* Block regions
/-------------------------------------------------------------- */
.inner .block-region {
  background: #4c4c4c;
  color: #E0B47A;
  text-shadow: 1px 1px #666;
}

.block:hover > .inner > .inner-inner > .fusion-edit {
  display: block;
}


/* Skinr previews
/-------------------------------------------------------------- */
/* Screenshot drop shadow */
#screenshot {
  box-shadow: 3px 3px 3px #000;
  -moz-box-shadow: 3px 3px 3px #000;
  -webkit-box-shadow: 3px 3px 3px #000;
}


/* Skinr overlay fixes
/-------------------------------------------------------------- */
form#skinr-ui-form fieldset {
  background: #fff;
  border: 1px solid #ccc;
}

form#skinr-ui-form fieldset legend {
  background: #fff;
  border: none;
}


/* Vertical tabs
/-------------------------------------------------------------- */
div.vertical-tabs {
  background: #3e3e3e;
  border: 1px solid #444;
}

div.vertical-tabs ul.vertical-tabs-list {
  border-top: 1px solid #444;
}

div.vertical-tabs ul.vertical-tabs-list li {
  background: #242424;
  border: 1px solid #444;
  border-top: none;
}

div.vertical-tabs ul.vertical-tabs-list li.selected {
  background: #3e3e3e;
}

div.vertical-tabs ul.vertical-tabs-list li.selected strong, 
div.vertical-tabs ul.vertical-tabs-list li.selected small {
  color: #fff;
}