/* $Id: local-sample.css,v 1.2 2010/07/02 23:14:21 eternalistic Exp $ */

/****************************/
/* LOCAL CSS                */
/****************************/

/* Put your custom CSS and CSS overrides in this file and  */
/* rename it local.css.  By restricting your CSS changes   */
/* to local.css, your changes will not be overwritten when */
/* upgrading to a new version of this theme.  You can also */
/* use a local-rtl.css file for the equivalent in RTL.     */

/* Steps to activate local.css:                       */
/* 1. Add your custom CSS to this file                */
/* 2. Rename this file to local.css                   */
/* 3. Clear cached data at admin/settings/performance */
