/* $Id: ie6-fixes.css,v 1.2 2010/07/02 23:14:21 eternalistic Exp $ */

/* Search box */
#search-box {
  width: 165px;
}

/* Primary menu */
#primary-menu ul.menu {
  float: right;
}

#primary-menu ul.menu li a:link,
#primary-menu ul.menu li a:visited {
  float: left;
}

#primary-menu ul.menu li:hover ul.menu li.first,
#primary-menu ul.menu li.hover ul.menu li.first,
#primary-menu ul.menu li.sfHover ul.menu li.first {
  background: #646464;
}

/* Secondary menu */
#secondary-menu ul.links {
  float: right;
}

#secondary-menu ul.links li a:link,
#secondary-menu ul.links li a:visited {
  float: left;
}

/* Header site info inner */
#header-site-info-inner {
  height: 42px;
}

/* Dark transparent background inner */
.dark-transparent-background .inner {
  height: 390px;
}

/* Form inputs */
.form-item .form-radio,
.form-item .form-checkbox {
  background: none !important;
}